@@ -5,23 +5,23 @@
 
 typedef struct
   {
-    char lastsearch[256];
-    char type;
-    int search;
+    char lastsearch[256];	/* last searched regexp */
+    char type;			/* type of the last search (global/local) */
+    int search;			/* if true -- search again */
   }
 SearchAgain;
 
 typedef struct
   {
-    char filename[256];
-    long offset;
+    char filename[256];		/* name of file, where's the given offset */
+    long offset;		/* offset of the node */
   }
 Indirect;
 
 typedef struct
   {
-    char nodename[256];
-    long offset;
+    char nodename[256];		/* name of the node */
+    long offset;		/* offset of the node */
   }
 TagTable;
 
@@ -38,8 +38,8 @@ InfoHistory;
 typedef struct
   {
     int line;			/* line number of the place where the link is */
-    int row;			/* row number ----||---- */
-    int breakpos;		/* row number, where the links breaks to next line */
+    int col;			/* column number ----||---- */
+    int breakpos;		/* col number, where the links breaks to next line */
     int type;			/* type of link: 0 -  * menu::,
 				   1 -  * Comment: menu.
 				   2 -  *note note::
@@ -53,13 +53,18 @@ typedef struct
   }
 HyperObject;
 
-extern char *httpviewer;
-extern char *ftpviewer;
-extern char *maileditor;
-extern char *manlinks;
+extern char *httpviewer;	/* name of http viewer (i.e. lynx) */
+extern char *ftpviewer;		/* name of ftp viewer */
+extern char *maileditor;	/* name of maileditor */
+extern char *printutility;	/* name of the printing utility */
+extern char *manlinks;		/* man sections, considered to be highlighted 
+				 * as links */
+extern char *ignoredmacros;	/* groff/troff macros which are removed while
+				   preformatting manual page */
 
-extern char *tmpfilename1;
-extern char *tmpfilename2;
+extern char *tmpfilename1;	/* temporary filename */
+extern char *tmpfilename2;	/* second tmp filename--needed by regexp 
+				 * search, etc */
 
 extern SearchAgain searchagain;	/* a structure for "search again" feature */
 
@@ -68,6 +73,8 @@ extern int hyperobjectcount;
 extern Indirect *indirect;	/* an array of indirect entries [1 to n] */
 extern int IndirectEntries;	/* number of indirect entries */
 extern TagTable *tag_table;	/* an array of tag table entries [1 to n] */
+extern long FirstNodeOffset;	/* offset of the first node in info file */
+extern char FirstNodeName[256];	/* name of the first node in info file */
 extern int TagTableEntries;	/* number of tag table entries */
 extern int maxx, maxy;		/* maximum dimensions of screen */
 extern InfoHistory infohistory;
@@ -89,9 +96,20 @@ extern int LongManualLinks;	/* Causes manual link sections to be treated
 				   as long names (i.e. 3x11 instead of 3) */
 extern char *ManOptions;	/* options passed to the `man' program */
 extern char *StderrRedirection;	/* shell code to redirect stderr output */
+extern int FilterB7;		/* convert 0xb7 values in man pages to 'o'? */
+extern int ConfirmQuit;		/* determines if pinfo should ask for quit 
+				   confirmation */
+extern int QuitConfirmDefault;	/* determines the deafult answer to yes/no
+				   dialog, when finishing work with pinfo */
+extern int ClearScreenAtExit;	/* determines if pinfo should clear the screen
+				   at exit */
+extern int quote_ignored;	/* quote ignored macros when watching page */
 
-void inithistory ();
+void inithistory ();		/* initialize history (see struct above) 
+				 * variables for `lastread' history */
 void addinfohistory (char *file, char *node, int cursor, int pos);
-void dellastinfohistory ();
+				/* adds a history entry to the info file
+				 * `lastread' history */
+void dellastinfohistory ();	/* deletes last history entry */
 
 #endif
