@@ -1,5 +1,7 @@
 #include "common_includes.h"
 
+RCSID("$Id: filehandling_functions.c,v 1.27 2000/01/27 11:38:15 misiek Exp $")
+
 typedef struct
   {
     char *suffix;
@@ -57,7 +59,7 @@ dirpage_lookup (char **type, char ***message, long *lines,
 #define Lines (*lines)
   FILE *id = 0;
   int filenamelen = strlen (filename);
-  int goodHit = 0;
+  int goodHit = 0, perfectHit = 0;
   char name[256];
   char file[256];
   int i;
@@ -67,7 +69,7 @@ dirpage_lookup (char **type, char ***message, long *lines,
   read_item (id, type, message, lines);
   for (i = 1; i < Lines; i++)	/* initialize node-links for every line */
     {
-      if ((Message[i][0] == '*') && (Message[i][1] == ' '))
+      if ((Message[i][0] == '*') && (Message[i][1] == ' ') && (!perfectHit))
 	{
 	  char *nameend = strchr (Message[i], ':');
 	  if (nameend)
@@ -97,12 +99,14 @@ dirpage_lookup (char **type, char ***message, long *lines,
 				      *first_node = xmalloc (strlen (tmp) + 1);
 				      strcpy ((*first_node), tmp);
 				    }
-				  fclose (id);
+				  fclose (id);	/* we don't need dirfile/badly matched infofile open anymore */
 				  id = 0;
 				  if (!strstr (file, ".info"))
 				    strcat (file, ".info");
 				  id = openinfo (file, 0);
 				  goodHit = 1;
+				  if((nameend - Message[i]) - 2 == filenamelen)	/* the name matches perfectly to the query */
+				    perfectHit = 1;	/* stop searching for another matches, and use this one */
 				}
 			    }
 			}
@@ -736,21 +740,21 @@ initpaths ()
       if ((!globaldir) && (strcmp (curdir, "/usr/info")))
 	{
 	  infopaths[infopathcount] = xmalloc (15 + strlen (lang));
-	  strcpy (infopaths[infopathcount], "/usr/info");
+	  strcpy (infopaths[infopathcount], "/usr/info/");
 	  strcat (infopaths[infopathcount], lang);
 	  infopathcount++;
 	}
       if ((!localdir) && (strcmp (curdir, "/usr/local/info")))
 	{
 	  infopaths[infopathcount] = xmalloc (25 + strlen (lang));
-	  strcpy (infopaths[infopathcount], "/usr/local/info");
+	  strcpy (infopaths[infopathcount], "/usr/local/info/");
 	  strcat (infopaths[infopathcount], lang);
 	  infopathcount++;
 	}
       if ((!sharedir) && (strcmp (curdir, "/usr/share/info")))
 	{
 	  infopaths[infopathcount] = xmalloc (25 + strlen (lang));
-	  strcpy (infopaths[infopathcount], "/usr/share/info");
+	  strcpy (infopaths[infopathcount], "/usr/share/info/");
 	  strcat (infopaths[infopathcount], lang);
 	  infopathcount++;
 	}
