@@ -1,4 +1,7 @@
 #include "common_includes.h"
+
+RCSID("$Id: manual.c,v 1.59 2000/01/27 11:38:15 misiek Exp $")
+
 #include <ctype.h>
 #include <sys/stat.h>
 
@@ -35,6 +38,8 @@ int manualpos = 0;		/* number of the first line, which is painted on
 
 int manual_aftersearch = 0;	/* this is set if man page is now after search 
 				   operation */
+int manwidthChanged = 0;	/* this flag indicates whether the env variable
+				   $MANWIDTH was changed by pinfo */
 
 typedef struct
   {
@@ -175,11 +180,13 @@ handlemanual (char *name)	/*
   init_curses ();
   getmaxyx (stdscr, maxy, maxx);	/* if ncurses, get maxx and maxy */
   myendwin ();
-  {
-    char tmp[24];		/* set MANWIDTH environment variable */
-    snprintf (tmp, 24, "MANWIDTH=%d", maxx);
-    putenv (tmp);
-  }
+  if ((!getenv ("MANWIDTH")) || (manwidthChanged))
+    {
+      static char tmp[24];	/* set MANWIDTH environment variable */
+      snprintf (tmp, 24, "MANWIDTH=%d", maxx);
+      putenv (tmp);
+      manwidthChanged = 1;
+    }
 #else
   maxx = 80;
   maxy = 25;			/* otherwise hardcode 80x25... */
@@ -350,6 +357,17 @@ handlemanual (char *name)	/*
       return_value = manualwork ();	/* manualwork handles all
 					   actions when viewing man
 					   page */
+#ifdef getmaxyx
+      getmaxyx (stdscr, maxy, maxx);	/* if ncurses, get maxx and maxy */
+      if ((!getenv ("MANWIDTH")) || (manwidthChanged))
+	{
+	  static char tmp[24];	/* set MANWIDTH environment variable */
+	  snprintf (tmp, 24, "MANWIDTH=%d", maxx);
+	  putenv (tmp);
+	  manwidthChanged = 1;
+	}
+#endif
+      manual_aftersearch = 0;
       if (return_value != -1)	/* -1 is quit key */
 	{
 	  if (tmpfilename2)
@@ -671,11 +689,13 @@ manualwork ()			/* viewer function. Handles keyboard actions--main event loop */
   int i, selectedchanged;	/* tmp values */
 #ifdef getmaxyx
   getmaxyx (stdscr, maxy, maxx);	/* if ncurses, get maxx and maxy */
-  {
-    char tmp[24];		/* set MANWIDTH environment variable */
-    snprintf (tmp, 24, "MANWIDTH=%d", maxx);
-    putenv (tmp);
-  }
+  if ((!getenv ("MANWIDTH")) || (manwidthChanged))
+    {
+      static char tmp[24];	/* set MANWIDTH environment variable */
+      snprintf (tmp, 24, "MANWIDTH=%d", maxx);
+      putenv (tmp);
+      manwidthChanged = 1;
+    }
 #else
   maxx = 80;
   maxy = 25;			/* otherwise hardcode 80x25... */
@@ -731,7 +751,13 @@ manualwork ()			/* viewer function. Handles keyboard actions--main event loop */
 	      curs_set (0);
 	      noecho ();
 	      move (maxy - 1, 0);
+#ifdef HAVE_BKGDSET
+	      bkgdset (' ' | bottomline);
+	      clrtoeol ();
+	      bkgdset (0);
+#else
 	      myclrtoeol ();
+#endif
 	      attrset (normal);
 
 	      manuallinks[ManualLinks].carry = 0;
@@ -755,7 +781,13 @@ manualwork ()			/* viewer function. Handles keyboard actions--main event loop */
 	      curs_set (0);
 	      noecho ();
 	      move (maxy - 1, 0);
+#ifdef HAVE_BKGDSET
+	      bkgdset (' ' | bottomline);
+	      clrtoeol ();
+	      bkgdset (0);
+#else
 	      myclrtoeol ();
+#endif
 	      attrset (normal);
 	      if (token)	/*
 				 * convert string to long.
@@ -795,7 +827,13 @@ manualwork ()			/* viewer function. Handles keyboard actions--main event loop */
 	      token = getstring (_ ("Enter command: "));	/* get users cmd */
 	      noecho ();
 	      move (maxy - 1, 0);
+#ifdef HAVE_BKGDSET
+	      bkgdset (' ' | bottomline);
+	      clrtoeol ();
+	      bkgdset (0);
+#else
 	      myclrtoeol ();
+#endif
 	      attrset (normal);
 
 	      myendwin ();
@@ -852,7 +890,13 @@ manualwork ()			/* viewer function. Handles keyboard actions--main event loop */
 	      curs_set (0);
 	      noecho ();
 	      move (maxy - 1, 0);
+#ifdef HAVE_BKGDSET
+	      bkgdset (' ' | bottomline);
+	      clrtoeol ();
+	      bkgdset (0);
+#else
 	      myclrtoeol ();
+#endif
 	      attrset (normal);
 	      pinfo_re_comp (token);	/* compile regexp expression */
 	      for (i = manualpos + 1; i < ManualLines - 1; i++)
@@ -950,6 +994,8 @@ manualwork ()			/* viewer function. Handles keyboard actions--main event loop */
 	      (key == keys.end_2))
 	    {
 	      manualpos = ManualLines - (maxy - 1);
+	      if (manualpos < 0) 
+	        manualpos = 0;
 	      selected = ManualLinks - 1;
 	    }
 /*===========================================================================*/
@@ -1230,7 +1276,13 @@ showmanualscreen ()		/* show the currently visible part of manpage */
       if (len)
 	manual[i][len - 1] = '\n';
     }
+#ifdef HAVE_BKGDSET
+  bkgdset (' '|normal);
+#endif
   clrtobot ();			/* and clear to bottom */
+#ifdef HAVE_BKGDSET
+  bkgdset (0);
+#endif
   add_highlights ();		/* add highlights */
   attrset (bottomline);		/* draw bottomline with user informations */
   mymvhline (0, 0, ' ', maxx);
@@ -1297,7 +1349,13 @@ mvaddstr_manual (int y, int x, char *str)	/* print a manual line */
 	}
     label_skip_other:;
     }
+#ifdef HAVE_BKGDSET
+  bkgdset (' ' | normal);
+  clrtoeol ();
+  bkgdset (0);
+#else
   myclrtoeol ();
+#endif
 #ifndef ___DONT_USE_REGEXP_SEARCH___
   if ((h_regexp_num) || (manual_aftersearch))
     {
@@ -1312,7 +1370,9 @@ mvaddstr_manual (int y, int x, char *str)	/* print a manual line */
 	    {
 	      int n = pmatch[0].rm_eo - pmatch[0].rm_so, k;
 	      int rx = pmatch[0].rm_so + tmpstr - strippedline;
+	      int curY,curX;
 	      char tmpchr;
+	      getyx(stdscr,curY,curX);
 	      tmpchr = strippedline[rx + n];
 	      strippedline[rx + n] = 0;
 	      attrset (searchhighlight);
@@ -1320,6 +1380,7 @@ mvaddstr_manual (int y, int x, char *str)	/* print a manual line */
 	      attrset (normal);
 	      strippedline[rx + n] = tmpchr;
 	      tmpstr = tmpstr + pmatch[0].rm_eo;
+	      move(curY,curX);
 	    }
 	}
     }
