@@ -1,6 +1,8 @@
 
 #include "common_includes.h"
 
+RCSID("$Id: video.c,v 1.17 2000/01/27 11:38:16 misiek Exp $")
+
 void info_add_highlights (int pos, int cursor, long lines, char **message);
 
 void
@@ -52,15 +54,25 @@ void
 showscreen (char **message, char *type, long lines, long pos, long cursor)
 {
   long i;
+#ifdef HAVE_BKGDSET
+  bkgdset (' ' | normal);
+#endif
   for (i = pos; (i < lines) && (i < pos + maxy - 2); i++)
     {
       int tmp = strlen (message[i]) - 1;
       message[i][tmp] = 0;
       mvaddstr (i + 1 - pos, 0, message[i]);
+#ifdef HAVE_BKGDSET
+      clrtoeol ();
+#else
       myclrtoeol ();
+#endif
       message[i][tmp] = '\n';
     }
   clrtobot ();
+#ifdef HAVE_BKGDSET
+  bkgdset (0);
+#endif
   attrset (bottomline);
   mymvhline (maxy - 1, 0, ' ', maxx);
   move (maxy - 1, 0);
